==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/polls/admin_deleteanswer.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Polls                                                     *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: admin_deleteanswer.php,v 1.4 2004/04/08 00:44:34 kazuyan Exp $ */

	$phpgw_info = array();
	$GLOBALS['phpgw_info']['flags'] = array(
		'admin_only'              => True,
		'currentapp'              => 'polls',
		'enable_nextmatchs_class' => True,
		'admin_header'            => True
	);
	if ($HTTP_GET_VARS['confirm'])
	{
		$GLOBALS['phpgw_info']['flags']['noheader'] = True;
		$GLOBALS['phpgw_info']['flags']['nonavbar'] = True;
		$GLOBALS['phpgw_info']['flags']['admin_header'] = False;
	}
	include('../header.inc.php');

	if ($_GET['confirm'])
	{
		$GLOBALS['phpgw']->db->query('DELETE FROM phpgw_polls_data WHERE '
			. 'vote_id = ' . intval($_GET['vote_id']) . ' AND poll_id = ' . intval($_GET['poll_id']), __LINE__, __FILE__);
		Header('Location: ' . $GLOBALS['phpgw']->link('/polls/admin.php','show=answers'));
	}
	else
	{
		echo '<p><br><table border="0" width="40%" align="center"><tr><td align="center" colspan="center">';
		echo lang('Are you sure want to delete this answer ?') . '</td></tr>';
		echo '<tr><td align="left"><a href="' . $GLOBALS['phpgw']->link('/polls/admin.php','show=answers') . '">' . lang('No') . '</td>';
		echo '    <td align="right"><a href="' . $GLOBALS['phpgw']->link('/polls/admin_deleteanswer.php','vote_id='
			. intval($_GET['vote_id']) . '&poll_id=' . intval($_GET['poll_id']) . '&confirm=True') . '">' . lang('Yes') . '</td></tr>';
		echo '</table>';
	}
	$GLOBALS['phpgw']->common->phpgw_footer();
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/polls/admin_deleteanswer.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Polls                                                     *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: admin_deleteanswer.php,v 1.5 2007/09/10 19:29:29 kazuyan Exp $ */

	$phpgw_info = array();
	$GLOBALS['phpgw_info']['flags'] = array(
		'admin_only'              => True,
		'currentapp'              => 'polls',
		'enable_nextmatchs_class' => True,
		'admin_header'            => True
	);
	if ($HTTP_GET_VARS['confirm'])
	{
		$GLOBALS['phpgw_info']['flags']['noheader'] = True;
		$GLOBALS['phpgw_info']['flags']['nonavbar'] = True;
		$GLOBALS['phpgw_info']['flags']['admin_header'] = False;
	}
	include('../header.inc.php');

	$_GET['poll_id'] = intval($_GET['poll_id']);
	$_GET['vote_id'] = intval($_GET['vote_id']);

	if ( isset($_GET['confirm']) && $_GET['confirm'] )
	{
		$GLOBALS['phpgw']->db->query('DELETE FROM phpgw_polls_data '
			. " WHERE vote_id = {$_GET['vote_id']} AND poll_id = {$_GET['poll_id']}", __LINE__, __FILE__);

		Header('Location: ' . $GLOBALS['phpgw']->link('/polls/admin.php', array('show' => 'answers') ) );
	}
	else
	{
		echo '<p><br><table border="0" width="40%" align="center"><tr><td align="center" colspan="center">';
		echo lang('Are you sure want to delete this answer ?') . '</td></tr>';
		echo '<tr><td align="left"><a href="' . $GLOBALS['phpgw']->link('/polls/admin.php','show=answers') . '">' . lang('No') . '</td>';
		echo '    <td align="right"><a href="' . $GLOBALS['phpgw']->link('/polls/admin_deleteanswer.php', 
				array
				(
					'vote_id'	=> $_GET['vote_id'],
					'poll_id'	=> $_GET['poll_id'],
					'confirm'	=> 'True'
				)) . '">' . lang('Yes') . '</td></tr>';
		echo '</table>';
	}
	$GLOBALS['phpgw']->common->phpgw_footer();
?>
